reactRouterExample: Run reactRouterExample example

View source: R/reactRouterExample.R

reactRouterExampleR Documentation

Run reactRouterExample example

Description

Launch a Shiny example app or list the available examples. Use 'reactRouter::reactRouterExample("basic")' to run a showcase app.

Usage

reactRouterExample(example = NULL, ...)

Arguments

example

The name of the example to run, or 'NULL' to print and invisibly return the list of available examples.

...

Additional arguments to pass to 'shiny::runApp()'.

Value

When 'example' is 'NULL', invisibly returns a character vector of example names (also printed via 'message()'). Otherwise this function normally does not return; interrupt R to stop the application (usually by pressing Ctrl+C or Esc).

See Also

shiny.blueprint::runExample(), which this function is adapted from.


reactRouter documentation built on May 10, 2026, 5:07 p.m.