| useAsyncError | R Documentation |
https://api.reactrouter.com/v7/functions/react-router.useAsyncError.html
useAsyncError(
into = NULL,
as = "children",
selector = NULL,
render = NULL,
...
)
into |
A component (HTML tag or shiny.react-based element) that will receive the hook data as the specified prop. |
as |
Character. The name of the component's prop to inject the hook
data into (by default |
selector |
Character. Optional key to extract from the hook data object.
If |
render |
Optional |
... |
Additional props to pass to the component. |
Calls the useAsyncError() hook and injects the rejection reason
(or a selector from it) as a prop of the into
component. Must be rendered inside the errorElement of an
Await so the hook can pick up the rejected promise's error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.