| useFetchers | R Documentation |
https://api.reactrouter.com/v7/functions/react-router.useFetchers.html
useFetchers(into = NULL, as = "children", selector = NULL, render = NULL, ...)
into |
A component (HTML tag or shiny.react-based element) that will receive the hook data as the specified prop. |
as |
Character. The name of the component's prop to inject the hook
data into (by default |
selector |
Character. Optional key to extract from the hook data object.
If |
render |
Optional |
... |
Additional props to pass to the component. |
Calls the useFetchers() hook and injects the result (or a
selector mapped over each fetcher) as a prop of the
into component. Returns an array of all active fetchers.
Useful for showing a global loading indicator.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.