| useMatch | R Documentation |
https://api.reactrouter.com/v7/functions/react-router.useMatch.html
useMatch(
into = NULL,
as = "children",
selector = NULL,
render = NULL,
pattern,
...
)
into |
A component (HTML tag or shiny.react-based element) that will receive the hook data as the specified prop. |
as |
Character. The name of the component's prop to inject the hook
data into (by default |
selector |
Character. Optional key to extract from the hook data object.
If |
render |
Optional |
pattern |
Character. The path pattern to match against
(e.g. |
... |
Additional props to pass to the component. |
Calls the useMatch() hook and injects the result (or a
selector from it) as a prop of the into component.
Returns NULL if no match.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.