| useMatches | R Documentation |
https://api.reactrouter.com/v7/functions/react-router.useMatches.html
useMatches(into = NULL, as = "children", selector = NULL, render = NULL, ...)
into |
A component (HTML tag or shiny.react-based element) that will receive the hook data as the specified prop. |
as |
Character. The name of the component's prop to inject the hook
data into (by default |
selector |
Character. Optional key to extract from the hook data object.
If |
render |
Optional |
... |
Additional props to pass to the component. |
Calls the useMatches() hook and injects the result (or a
selector extracted from each match) as a prop of the
into component. Only works inside a data router.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.