| useRevalidator | R Documentation |
https://api.reactrouter.com/v7/functions/react-router.useRevalidator.html
useRevalidator(
into = NULL,
as = "children",
selector = "state",
render = NULL,
...
)
into |
A component (HTML tag or shiny.react-based element) that will receive the hook data as the specified prop. |
as |
Character. The name of the component's prop to inject the hook
data into (by default |
selector |
Character. Optional key to extract from the hook data object.
If |
render |
Optional |
... |
Additional props to pass to the component. |
Calls the useRevalidator() hook and injects the result (or a
selector from it) as a prop of the into component.
Returns the revalidation state ("idle" or "loading").
Useful for showing loading feedback during manual or polling revalidation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.