View source: R/reactRouterExample.R
| reactRouterExample | R Documentation |
Launch a Shiny example app or list the available examples. Use 'reactRouter::reactRouterExample("basic")' to run a showcase app.
reactRouterExample(example = NULL, ...)
example |
The name of the example to run, or 'NULL' to print and invisibly return the list of available examples. |
... |
Additional arguments to pass to 'shiny::runApp()'. |
When 'example' is 'NULL', invisibly returns a character vector of example names (also printed via 'message()'). Otherwise this function normally does not return; interrupt R to stop the application (usually by pressing Ctrl+C or Esc).
shiny.blueprint::runExample(), which this function is
adapted from.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.