| useOutletContext | R Documentation |
https://api.reactrouter.com/v7/functions/react-router.useOutletContext.html
useOutletContext(
into = NULL,
as = "children",
selector = NULL,
render = NULL,
...
)
into |
A component (HTML tag or shiny.react-based element) that will receive the hook data as the specified prop. |
as |
Character. The name of the component's prop to inject the hook
data into (by default |
selector |
Character. Optional key to extract from the hook data object.
If |
render |
Optional |
... |
Additional props to pass to the component. |
Calls the useOutletContext() hook and injects the context value
(or a selector from it) as a prop of the into
component. The context is whatever was passed to the parent route's
Outlet(context = ...) call.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.