| useRouteLoaderData | R Documentation |
https://api.reactrouter.com/v7/functions/react-router.useRouteLoaderData.html
useRouteLoaderData(
into = NULL,
as = "children",
selector = NULL,
render = NULL,
routeId,
...
)
into |
A component (HTML tag or shiny.react-based element) that will receive the hook data as the specified prop. |
as |
Character. The name of the component's prop to inject the hook
data into (by default |
selector |
Character. Optional key to extract from the hook data object.
If |
render |
Optional |
routeId |
Character. The route ID to fetch loader data from. |
... |
Additional props to pass to the component. |
Calls the useRouteLoaderData() hook and injects the result (or a
selector from it) as a prop of the into component.
Accesses loader data from any route by its routeId.
Only works inside a data router.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.